@@ -12,5 +12,8 @@
 //!
 //! # v2_0_1
 //! The [v2_0_1](v2_0_1) module contains the `ocpp 2.0.1` implementation
+/// tests
+#[cfg(test)]
+pub mod tests;
 pub mod v1_6;
 pub mod v2_0_1;
