@@ -1,4 +1,4 @@
-use crate::v1_6::types::ResetStatus;
+use crate::v1_6::types::{ResetRequestStatus, ResetResponseStatus};
 
 /// This contains the field definition of the ResetRequest PDU sent by the Central System to the Charge Point. See also Reset
 #[derive(serde::Serialize, serde::Deserialize, Debug, Clone, PartialEq)]
@@ -6,7 +6,7 @@ use crate::v1_6::types::ResetStatus;
 pub struct ResetRequest {
     /// Required. This contains the type of reset that the Charge Point should perform.
     #[serde(rename = "type")]
-    pub kind: ResetStatus,
+    pub kind: ResetRequestStatus,
 }
 
 /// This contains the field definition of the ResetResponse PDU sent by the Charge Point to the Central System inresponse to a ResetRequest PDU. See also Reset
@@ -14,5 +14,5 @@ pub struct ResetRequest {
 #[serde(rename_all = "camelCase")]
 pub struct ResetResponse {
     // Required. This indicates whether the Charge Point is able to perform the reset.
-    pub status: ResetStatus,
+    pub status: ResetResponseStatus,
 }
