@@ -1,4 +1,5 @@
 //! Contains a case insensitive identifier to use for the authorization and the type of authorization to support multiple forms of identifiers.
+use crate::v2_0_1::helpers::validator::validate_identifier_string;
 use validator::Validate;
 
 /// Contains a case insensitive identifier to use for the authorization and the
@@ -9,7 +10,7 @@ use validator::Validate;
 #[serde(rename_all = "camelCase")]
 pub struct AdditionalInfoType {
     /// This field specifies the additional IdToken
-    #[validate(length(min = 0, max = 36))]
+    #[validate(length(min = 0, max = 36), custom = "validate_identifier_string")]
     pub additional_id_token: String,
     /// This defines the type of the additionalIdToken. This is a custom type, so the implementation needs to be agreed upon by all involved parties.
     #[validate(length(min = 0, max = 50))]
