@@ -17,8 +17,3 @@ pub mod messages;
 
 /// helper functions
 pub mod helpers;
-
-
-/// tests
-#[cfg(test)]
-pub mod tests;
\ No newline at end of file
